@@ -1,7 +1,7 @@
 /***************************************************************************
  * aspline.c -- aspline does an Akima spline interpolation.                *
  *                                                                         *
- * spline is  David Frey, 1996, 1998, 1999, 2002                          *
+ * spline is (c) David Frey, 1996, 1998, 1999, 2002                        *
  *                                                                         *
  * This program is free software; you can redistribute it and/or modify it *
  * under the terms of the GNU General Public License as published by the   *
@@ -15,7 +15,7 @@
  *                                                                         *
  * You should have received a copy of the GNU General Public License       *
  * along with this program; if not, write to the Free Software Foundation, *
- * Inc., 59 Temple Place Suite 330, Boston, MA 02111-1307 USA.             *
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
 
 #include <stdio.h>
@@ -387,7 +387,7 @@ int main(int argc, char *argv[])
       case 'u': ulimit=strtod(optarg, NULL); calclimit=0; break;
       case 'v': verbose++; break;
       case 'V': fprintf(stderr, "%s version %s\n"
-"Akima spline interpolation  1996-1998 David Frey.\n"
+"Akima spline interpolation (c) 1996-1998 David Frey.\n"
 "This is free software; see the GNU General Public Licence version 2 or "
 "later\n"
 "for copying conditions.\n"
